% Baccala & Sameshima. Overcoming the limitations of correlation analysis 
% for many simultaneously processed neural structures, Progress in Brain 
% Research, 130:3347, 2001.
%            http://dx.doi.org/10.1016/S0079-6123(01)30004-3
% 
% Example VAR(7) with loop and feedback

clear; clc
N=20000;
disp('======================================================================');
disp('                       Linear VAR(2) Model')
disp('        Baccala & Sameshima. Prog Brain Research, 130:3347, 2001.')
disp('  x1-->x2  x1-->x3  x2-->x3 x3-->x4 x4==>x5 x5-->x1  x5-->x4 x6==>x7');
disp('======================================================================');

randn('state', sum(100*clock))
ei=randn(7,N);
x1=zeros(1,N);
x2=zeros(1,N);
x3=zeros(1,N);
x4=zeros(1,N);
x5=zeros(1,N);
x6=zeros(1,N);
x7=zeros(1,N);
% Variables initialization
for t=1:4,
   x1(t)=randn(1); x2(t)=randn(1); x3(t)=randn(1); x4(t)=randn(1);
   x5(t)=randn(1); x6(t)=randn(1); x7(t)=randn(1); 
end;

for t=5:N,
   x1(t) = 0.95*sqrt(2)*x1(t-1) - 0.9025*x1(t-2) + 0.5*x5(t-2) + ei(1,t);
   x2(t) = -0.5*x1(t-1) + ei(2,t);
   x3(t) =  0.2*x1(t-1) + 0.4*x2(t-2) + ei(3,t);
   x4(t) = -0.5*x3(t-1) + 0.25*sqrt(2)*x4(t-1) + 0.25*sqrt(2)*x5(t-2) + ei(4,t);
   x5(t) = -0.25*sqrt(2)*x4(t-1) + 0.25*sqrt(2)*x5(t-1) + ei(5,t);
   x6(t) = 0.95*sqrt(2)*x6(t-1) - 0.9025*x6(t-2) + ei(6,t);
   x7(t) = -0.1*x6(t-2) + ei(7,t);   
end;


%chLabels = []; % or 
chLabels = {'x_1';'x_2';'x_3';'x_4';'x_5';'x_6';'x_7'};

nDiscard=1000; % number of points discarded at beginning of series
nPoints=5000;   % number of analyzed samples points

y=[x1' x2' x3' x4' x5' x6' x7']; % data must be organized column-wise
u=y(nDiscard+1:nDiscard+nPoints,:);
clear y x1 x2 x3 x4 x5 x6 x7 ei
[nSegLength,nChannels]=size(u);

%==========================================================================
%                     PDCn estimation and analysis parameters
%==========================================================================
run example_analysis_parameters % Setting default paramaters 

run example_pre_processing      % Detrending and/or standardization

run example_mvar_estimation     % Estimating VAR and testing adequacy of 
                                % VAR model as well as performing GCT and ICT.

%=======Overriding some default parameters for plotting and analysis=======

flgPrinting = [1 1 1 1 1 0 2]; % overriding default setting

% alpha=0.05;         % Significance level
% gct_signif = 0.05;  % Granger causality test significance level
% igct_signif = 0.05; % Instantaneous GCT significance level

metric = 'diag';

run example_pdc_analysis

%save baccala2001b_gPDC

%==========================================================================
%                        PDCn Matrix Layout Plotting
%==========================================================================
w_max=fs/2;
   
for kflgColor = flgColor,
   h=figure;
   set(h,'NumberTitle','off','MenuBar','none', ...
      'Name', 'Baccal & Sameshima (2001b) Linear model')
   [hxlabel hylabel] = pdc_xplot(c,...
      flgPrinting,fs,w_max,chLabels,kflgColor);
   pdc_xplot_title(alpha,metric);
   [ax,hT]=suplabel(['Linear model ' ...
      int2str(nPoints) ' data points.'],'t');
   set(hT,'FontSize',12); % Title font size
end;

disp('')
disp('==>In the original article the amplitude PDC has been plotted.')
disp('    Here we preferred squared PDC.')
disp('')

disp('======================================================================');
disp('      This completes the example Linear VAR[2] Model')
disp('        Baccala & Sameshima. Prog Brain Research, 130:3347, 2001.')
disp('  x1-->x2  x1-->x3  x2-->x3 x3-->x4 x4==>x5 x5-->x1  x5-->x4 x6==>x7');
disp('======================================================================');

